RagContextManager

Struct RagContextManager 

pub struct RagContextManager<R: Retriever, G: GroundingStrategy = PrependStrategy> { /* private fields */ }
A ContextManager that retrieves documents and injects them as grounded context.

Implementations

Source

impl<R: Retriever> RagContextManager<R, PrependStrategy>

pub fn new(retriever: R) -> Self

Create a new RagContextManager with PrependStrategy as the default grounding.

Source

impl<R: Retriever, G: GroundingStrategy> RagContextManager<R, G>

pub fn with_grounding<G2: GroundingStrategy>( self, grounding: G2, ) -> RagContextManager<R, G2>

Set the grounding strategy used to format retrieved documents.

pub fn with_max_docs(self, max_docs: usize) -> Self

Maximum number of retrieved documents to inject (default: 5).