pub struct RagContextManager<R: Retriever, G: GroundingStrategy = PrependStrategy> { /* private fields */ }Expand description
A ContextManager that retrieves documents and injects them as grounded context.
Implementations
Sourceimpl<R: Retriever> RagContextManager<R, PrependStrategy>
impl<R: Retriever> RagContextManager<R, PrependStrategy>
Sourceimpl<R: Retriever, G: GroundingStrategy> RagContextManager<R, G>
impl<R: Retriever, G: GroundingStrategy> RagContextManager<R, G>
Sourcepub fn with_grounding<G2: GroundingStrategy>(
self,
grounding: G2,
) -> RagContextManager<R, G2>
pub fn with_grounding<G2: GroundingStrategy>( self, grounding: G2, ) -> RagContextManager<R, G2>
Set the grounding strategy used to format retrieved documents.
Sourcepub fn with_max_docs(self, max_docs: usize) -> Self
pub fn with_max_docs(self, max_docs: usize) -> Self
Maximum number of retrieved documents to inject (default: 5).